@@ -30,15 +30,14 @@
 #' versions greater than 0.2.0 and will eventually be removed.
 #'
 #' @param ... Use to pass any other parameters to the API.
-#' 
+#'
 #' @param tidy If `TRUE`, converts tibble names to snakecase.
 #'
 #' @seealso [nomis_data_info()]
 #' @seealso [nomis_get_data()]
 #' @seealso [nomis_overview()]
 #'
-#' @return A tibble with metadata options for queries using
-#' [nomis_get_data()].
+#' @return A tibble with metadata options for queries using [nomis_get_data()].
 #' @export
 #'
 #' @examples
@@ -92,10 +91,12 @@ nomis_get_metadata <- function(id, concept = NULL, type = NULL, search = NULL,
     df1 <- tibble::as_tibble(
       as.data.frame(no_code_q$components.dimension)
     )
-    
+
     names(no_code_q) <- gsub("components.timedimension.", "",
-                             names(no_code_q), fixed = TRUE)
-    
+      names(no_code_q),
+      fixed = TRUE
+    )
+
     no_code_q <- no_code_q[c("codelist", "conceptref")]
 
     df <- bind_rows(df1, no_code_q)
@@ -127,7 +128,7 @@ nomis_get_metadata <- function(id, concept = NULL, type = NULL, search = NULL,
 
     dots_query <- paste0(dots_list, collapse = "")
 
-    df <- tibble::as.tibble(rsdmx::readSDMX(
+    df <- tibble::as_tibble(rsdmx::readSDMX(
       paste0(
         base_url, id, "/", concept,
         type_query, "/def.sdmx.xml?",
@@ -140,6 +141,6 @@ nomis_get_metadata <- function(id, concept = NULL, type = NULL, search = NULL,
   if (tidy) {
     names(df) <- snakecase::to_snake_case(names(df))
   }
-  
+
   df
 }
